function [e,f] = boundaries(y1, y2, alpha01, alpha02, C1,C2)
% boundaries - compute lower and upper bound on possible new values for alpha01 for SMO 
%              (for 1-norm soft margin SVM/SKM classifier)
%
% [e,f] = boundaries(y1, y2, alpha01, alpha02, C)
%
%
% The inputs are
%   y1       - label corresponding to alpha01
%   y2       - label corresponding to alpha02
%   alpha01  - previous value for alpha01
%   alpha02  - previous value for alpha02
%   C        - hyperparameter: weight of the penalty term in the SVM cost function
%
% The outputs are
%   e        - lower bound on possible new values for alpha01
%   f        - upper bound on possible new values for alpha01
%
% Gert Lanckriet, March 2004.


if (y1==y2),
    e = max([0 alpha01+alpha02-C2]);
    f = min([C1 alpha01+alpha02]);
else
    e = max([0 alpha01-alpha02]);
    f = min([C1 C2+alpha01-alpha02]);
end

