function [A,B]=svm_probabilities(deci,Y);
%        [A,B]=svm_probabilities(deci,Y);
%Input parameters:
%deci = array of SVM decision values
%Y = array of booleans: is the example Yed +1?
%prior1 = number of positive examples
%prior0 = number of negative examples
%Outputs:
%A, B = parameters of sigmoid
prior1=sum(Y==1);
prior0=sum(Y~=1);

%%//Parameter setting
maxiter=100;   %% //Maximum number of iterations
minstep=1e-10; %% //Minimum step taken in line search
sigma=1e-3;    %% //Set to any value > 0
%%Construct initial values: target support in array t,
%% initial function value in fval
hiTarget=(prior1+1.0)/(prior1+2.0); loTarget=1/(prior0+2.0);
n=length(Y); %% // Total number of data

idx1=find(Y==1);
t=loTarget*ones(1,n);
t(idx1)=hiTarget;

A=0.0;
B=log((prior0+1.0)/(prior1+1.0));
fApB=deci*A+B;
posidx=logical(fApB>=0);
fval=sum(t(posidx).*fApB(posidx)+log(1+exp(-fApB(posidx))))+...
    sum((t(~posidx)-1).*fApB(~posidx)+log(1+exp(fApB(~posidx))));

for it = 1:maxiter,
    %%//Update Gradient and Hessian (use H' = H + sigma I)
    p=zeros(1,n);
    q=zeros(1,n);

    fApB=deci*A+B;
    posidx=logical(fApB>=0);
    p(posidx)=exp(-fApB(posidx))./(1.0+exp(-fApB(posidx)));
    q(posidx)=1.0./(1.0+exp(-fApB(posidx)));
    p(~posidx)=1.0./(1.0+exp(fApB(~posidx)));
    q(~posidx)=exp(fApB(~posidx))/(1.0+exp(fApB(~posidx)));
    pq=p.*q;
    h11=pq*deci'.^2+sigma;
    h22=sum(pq)+sigma;
    h21=pq*deci';
    d1=t-p;
    g1=d1*deci';
    g2=sum(d1);



    if (abs(g1)<1e-5 & abs(g2)<1e-5) %%//Stopping criteria
        break
    end
    %%//Compute modified Newton directions
    det=h11*h22-h21*h21;
    dA=-(h22*g1-h21*g2)/det;
    dB=-(-h21*g1+h11*g2)/det;
    gd=g1*dA+g2*dB;
    stepsize=1;
    while (stepsize >= minstep),       %%//Line search
        newA=A+stepsize*dA;
        newB=B+stepsize*dB;

        fApB=deci*newA+newB;
        posidx=logical(fApB >= 0);
        newf=sum(t(posidx).*fApB(posidx)+log(1+exp(-fApB(posidx))))+...
            sum((t(~posidx)-1).*fApB(~posidx)+log(1+exp(fApB(~posidx))));
        if (newf<fval+0.0001*stepsize*gd)
            A=newA;
            B=newB;
            fval=newf;
            break %%//Sufficient decrease satisfied
        else
            stepsize = stepsize/2.0;
        end
    end

    if (stepsize < minstep)
        fprintf('Line search fails');
        break
    end
end
    %fApB=deci*A+B;
    %posidx=logical(fApB>=0);
    %p(posidx)=exp(-fApB(posidx))./(1.0+exp(-fApB(posidx)));
    %p(~posidx)=1.0/(1.0+exp(fApB(~posidx)));
if (it >= maxiter)
    fprintf('Reaching maximum iterations');
end
